@@ -1,10 +1,11 @@
 pub mod import_map;
 
 use crate::module_loader::import_map::{
-    build_format_locale_map, build_import_map, build_time_format_locale_map, VEGA_PATH,
-    VEGA_THEMES_PATH,
+    build_format_locale_map, build_import_map, build_time_format_locale_map, JSDELIVR_URL,
+    VEGA_PATH, VEGA_THEMES_PATH,
 };
 use crate::VlVersion;
+use deno_core::url::Url;
 use deno_core::{ModuleLoadResponse, ModuleSourceCode, RequestedModuleType, ResolutionKind};
 use deno_emit::{LoadFuture, LoadOptions, Loader};
 use deno_graph::source::LoadResponse;
@@ -14,6 +15,7 @@ use deno_runtime::deno_core::{
 };
 use regex::Regex;
 use std::collections::HashMap;
+use std::str::FromStr;
 use std::sync::Arc;
 
 lazy_static! {
@@ -51,7 +53,6 @@ impl ModuleLoader for VlConvertModuleLoader {
     ) -> ModuleLoadResponse {
         let module_specifier = module_specifier.clone();
         let string_specifier = module_specifier.to_string();
-        // println!("load: {}", string_specifier);
 
         let code = if string_specifier.ends_with("vl-convert-rs.js") {
             // Load vl-convert-rs.js as an empty file
@@ -59,14 +60,13 @@ impl ModuleLoader for VlConvertModuleLoader {
             // run any code here
             "".to_string()
         } else {
+            let path = module_specifier.path();
+            let path = path.strip_prefix(JSDELIVR_URL).unwrap_or(path);
+            // strip the .js extension if it exists
+            let path = path.strip_suffix(".js").unwrap_or(path).to_string();
             IMPORT_MAP
-                .get(module_specifier.path())
-                .unwrap_or_else(|| {
-                    panic!(
-                        "Unexpected source file with path: {}",
-                        module_specifier.path()
-                    )
-                })
+                .get(&path)
+                .unwrap_or_else(|| panic!("Unexpected source file with path: {}", path))
                 .clone()
         };
 
@@ -98,11 +98,11 @@ pub struct VlConvertBundleLoader {
 impl VlConvertBundleLoader {
     pub fn new(index_js: String, embed_vl_version: VlVersion) -> Self {
         let name_version_re =
-            Regex::new(r"(?P<name>[^@]+)@v(?P<version>[0-9]+\.[0-9]+\.[0-9]+)").unwrap();
-        let vegalite_re = Regex::new(r#"("/-/vega-lite@v[0-9]+\.[0-9]+\.[0-9]+-[^"]+")"#).unwrap();
-        let vega_re = Regex::new(r#"("/-/vega@v[0-9]+\.[0-9]+\.[0-9]+-[^"]+")"#).unwrap();
+            Regex::new(r"(?P<name>[^@]+)@(?P<version>[0-9]+\.[0-9]+\.[0-9]+)").unwrap();
+        let vegalite_re = Regex::new(r#"("/npm/vega-lite@[0-9]+\.[0-9]+\.[0-9]+/\+esm")"#).unwrap();
+        let vega_re = Regex::new(r#"("/npm/vega@[0-9]+\.[0-9]+\.[0-9]+/\+esm")"#).unwrap();
         let vega_themes_re =
-            Regex::new(r#"("/-/vega-themes@v[0-9]+\.[0-9]+\.[0-9]+-[^"]+")"#).unwrap();
+            Regex::new(r#"("/npm/vega-themes@[0-9]+\.[0-9]+\.[0-9]+/\+esm")"#).unwrap();
         Self {
             index_js,
             name_version_re,
@@ -118,17 +118,15 @@ impl Loader for VlConvertBundleLoader {
     fn load(&self, module_specifier: &ModuleSpecifier, _options: LoadOptions) -> LoadFuture {
         let module_specifier = module_specifier.clone();
         let last_path_part = module_specifier.path().split('/').next_back().unwrap();
+        let path = module_specifier.path();
+        let path_no_js = path.strip_suffix(".js").unwrap_or(path).to_string();
+
         let code = if last_path_part == "vl-convert-index.js" {
             self.index_js.clone()
         } else {
             let mut src = IMPORT_MAP
-                .get(module_specifier.path())
-                .unwrap_or_else(|| {
-                    panic!(
-                        "Unexpected source file with path: {}",
-                        module_specifier.path()
-                    )
-                })
+                .get(&path_no_js)
+                .unwrap_or_else(|| panic!("Unexpected source file with path: {}", path))
                 .clone();
 
             if let Some(caps) = self.name_version_re.captures(module_specifier.path()) {
@@ -161,9 +159,18 @@ impl Loader for VlConvertBundleLoader {
         let code_bytes = code.into_bytes();
         let content: Arc<[u8]> = code_bytes.into_boxed_slice().into();
 
+        // Make new specifier with .js extension, so deno bundle knows the media type
+        let url = module_specifier.to_string();
+        let url_no_js = url.strip_suffix(".js").unwrap_or(&url).to_string();
+
+        let return_specifier =
+            Url::from_str(&format!("{}{}", url_no_js, ".js")).unwrap_or_else(|_| {
+                panic!("Failed to parse module specifier {url_no_js} with .js extension")
+            });
+
         Box::pin(async move {
             Ok(Some(LoadResponse::Module {
-                specifier: module_specifier.clone(),
+                specifier: return_specifier,
                 maybe_headers: None,
                 content,
             }))
